@@ -33,7 +33,7 @@ __export(events_lambda_exports, {
   handler: () => handler
 });
 module.exports = __toCommonJS(events_lambda_exports);
-var import_aws_sdk = require("aws-sdk");
+var import_client_eventbridge = require("@aws-sdk/client-eventbridge");
 
 // src/slack-events/signature.ts
 var crypto = __toESM(require("crypto"));
@@ -55,6 +55,7 @@ function verifyRequestSignature(options) {
 }
 
 // src/slack-events/events.lambda.ts
+var eventBridgeClient = new import_client_eventbridge.EventBridgeClient({});
 async function handler(event) {
   console.log("Event: %j", event);
   const response = {
@@ -62,14 +63,10 @@ async function handler(event) {
     body: ""
   };
   try {
-    if (!process.env.SLACK_SIGNING_SECRET)
-      throw new Error("The environment variable SLACK_SIGNING_SECRET is not defined");
-    if (!event.body)
-      throw new Error("Missing body");
-    if (!event.headers["X-Slack-Signature"])
-      throw new Error("Missing X-Slack-Signature");
-    if (!event.headers["X-Slack-Request-Timestamp"])
-      throw new Error("Missing X-Slack-Request-Timestamp");
+    if (!process.env.SLACK_SIGNING_SECRET) throw new Error("The environment variable SLACK_SIGNING_SECRET is not defined");
+    if (!event.body) throw new Error("Missing body");
+    if (!event.headers["X-Slack-Signature"]) throw new Error("Missing X-Slack-Signature");
+    if (!event.headers["X-Slack-Request-Timestamp"]) throw new Error("Missing X-Slack-Request-Timestamp");
     if (!verifyRequestSignature({
       body: event.body,
       requestSignature: event.headers["X-Slack-Signature"],
@@ -86,19 +83,16 @@ async function handler(event) {
       response.body = JSON.stringify({ challenge: body.challenge });
       return response;
     }
-    const eventBridge = new import_aws_sdk.EventBridge({ apiVersion: "2015-10-07" });
-    const putEvents = await eventBridge.putEvents({
-      Entries: [
-        {
-          Detail: event.body,
-          DetailType: "Slack Event",
-          Source: "slack",
-          Resources: [body.api_app_id],
-          EventBusName: process.env.EVENT_BUS_NAME,
-          Time: new Date(body.event_time)
-        }
-      ]
-    }).promise();
+    const putEvents = await eventBridgeClient.send(new import_client_eventbridge.PutEventsCommand({
+      Entries: [{
+        Detail: event.body,
+        DetailType: "Slack Event",
+        Source: "slack",
+        Resources: [body.api_app_id],
+        EventBusName: process.env.EVENT_BUS_NAME,
+        Time: new Date(body.event_time)
+      }]
+    }));
     console.log("Put events: %j", putEvents);
     return response;
   } catch (err) {
