@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -11,12 +14,10 @@ import typing_extensions
 from typeguard import check_type
 
 import aws_cdk._jsii
-import aws_cdk.aws_apigatewayv2_alpha._jsii
-import aws_cdk.aws_apigatewayv2_integrations_alpha._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cloudstructs", "0.6.29", __name__[0:-6], "cloudstructs@0.6.29.jsii.tgz"
+    "cloudstructs", "0.9.14", __name__[0:-6], "cloudstructs@0.9.14.jsii.tgz"
 )
 
 __all__ = [
